import { Injectable } from '@angular/core';

@Injectable({
  providedIn: 'root',
})
export class ClassService {
  constructor() {}

  // FUNCTIONS

  public getClassDetails(className: string): any {
    switch (className) {
      case 'Fighter':
        return this.fighter;
      case 'Barbarian':
        return this.barbarian;
      case 'Cleric':
        return this.cleric;
      case 'Monk':
        return this.monk;
      case 'Ranger':
        return this.ranger;
      case 'Rogue':
        return this.rogue;
      case 'Sorcerer':
        return this.sorcerer;
      case 'Warlock':
        return this.warlock;
      case 'Wizard':
        return this.wizard;
      case 'Paladin':
        return this.paladin;
      default:
        return this.notImplementedYet;
    }
  }

  // CLASS DETAILS

  public monk: any = {
    title: 'Mönch',
    description: `
      <p>Monks are united in their ability to magically harness the energy that flows in their bodies. Whether channeled as a striking display of combat prowess or a subtler focus of defensive ability and speed, this energy infuses all that a monk does.</p>
      <h4>Class Features</h4>
      <p>As a monk, you gain the following class features.</p>
      <h5 id="toc1"><span>Hit Points</span></h5>
      <p><strong>Hit Dice:</strong> 1d8 per monk level<br />
      <strong>Hit Points at 1st Level:</strong> 8 + your Constitution modifier<br />
      <strong>Hit Points at Higher Levels:</strong> 1d8 (or 5) + your Constitution modifier per monk level after 1st</p>
      <h5 id="toc2"><span>Proficiencies</span></h5>
      <p><strong>Armor:</strong> None<br />
      <strong>Weapons:</strong> Simple weapons, shortswords<br />
      <strong>Tools:</strong> Choose one type of artisan's tools or one musical instrument<br />
      <strong>Saving Throws:</strong> Strength, Dexterity<br />
      <strong>Skills:</strong> Choose two from Acrobatics, Athletics, History, Insight, Religion, and Stealth</p>
      <h5 id="toc3"><span>Equipment</span></h5>
      <p>You start with the following equipment, in addition to the equipment granted by your background:</p>
      <ul>
      <li>(a) a shortsword or (b) any simple weapon</li>
      <li>(a) a dungeoneer's pack or (b) an explorer's pack</li>
      <li>10 darts</li>
      </ul>`,
    features: [
      {
        name: 'Unarmored Defense',
        level: 1,
        description: `
          <p>Beginning at 1st level, while you are wearing no armor and not wielding a shield, your AC equals 10 + your Dexterity modifier + your Wisdom modifier.</p>
          `,
      },
      {
        name: 'Martial Arts',
        level: 1,
        description: `
          <p>At 1st level, your practice of martial arts gives you mastery of combat styles that use unarmed strikes and monk weapons, which are shortswords and any simple melee weapons that don't have the two-handed or heavy property.</p>
          <p>You gain the following benefits while you are unarmed or wielding only monk weapons and you aren't wearing armor or wielding a shield:</p>
          <ul>
          <li>You can use Dexterity instead of Strength for the attack and damage rolls of your unarmed strikes and monk weapons.</li>
          </ul>
          <ul>
          <li>You can roll a d4 in place of the normal damage of your unarmed strike or monk weapon. This die changes as you gain monk levels, as shown in the Martial Arts column of the Monk table.</li>
          </ul>
          <ul>
          <li>When you use the Attack action with an unarmed strike or a monk weapon on your turn, you can make one unarmed strike as a bonus action. For example, if you take the Attack action and attack with a quarterstaff, you can also make an unarmed strike as a bonus action, assuming you haven't already taken a bonus action this turn.</li>
          </ul>
          <p>Certain monasteries use specialized forms of the monk weapons. For example, you might use a club that is two lengths of wood connected by a short chain (called a nunchaku) or a sickle with a shorter, straighter blade (called a kama). Whatever name you use for a monk weapon, you can use the game statistics provided for the weapon on the Weapons page.</p>
          `,
      },
      {
        name: 'Ki',
        level: 2,
        description: `
          <p>Starting at 2nd level, your training allows you to harness the mystic energy of ki. Your access to this energy is represented by a number of ki points. Your monk level determines the number of points you have, as shown in the Ki Points column of the Monk table.</p>
          <p>You can spend these points to fuel various ki features. You start knowing three such features: Flurry of Blows, Patient Defense, and Step of the Wind. You learn more ki features as you gain levels in this class.</p>
          <p>When you spend a ki point, it is unavailable until you finish a short or long rest, at the end of which you draw all of your expended ki back into yourself. You must spend at least 30 minutes of the rest meditating to regain your ki points.</p>
          <p>Some of your ki features require your target to make a saving throw to resist the feature's effects. The saving throw DC is calculated as follows:</p>
          <p><strong>Ki save DC</strong> = 8 + your proficiency bonus + your Wisdom modifier</p>
          <ul>
          <li><strong>Flurry of Blows.</strong> Immediately after you take the Attack action on your turn, you can spend 1 ki point to make two unarmed strikes as a bonus action.</li>
          </ul>
          <ul>
          <li><strong>Patient Defense.</strong> You can spend 1 ki point to take the Dodge action as a bonus action on your turn.</li>
          </ul>
          <ul>
          <li><strong>Step of the Wind.</strong> You can spend 1 ki point to take the Disengage or Dash action as a bonus action on your turn, and your jump distance is doubled for the turn.</li>
          </ul>`,
      },
      {
        name: 'Unarmored Movement',
        level: 2,
        description: `
          <p>Starting at 2nd level, your speed increases by 10 feet while you are not wearing armor or wielding a shield. This bonus increases when you reach certain monk levels, as shown in the Monk table.</p>
          <p>At 9th level, you gain the ability to move along vertical surfaces and across liquids on your turn without falling during the move.</p>
          `,
      },
      {
        name: 'Dedicated Weapons (Optional)',
        level: 2,
        description: `
        <p>Also at 2nd level, you train yourself to use a variety of weapons as monk weapons, not just simple melee weapons and shortswords. Whenever you finish a short or long rest, you can touch one weapon, focus your ki on it, and then count that weapon as a monk weapon until you use this feature again.</p>
          <p>The chosen weapon must meet these criteria:</p>
          <ul>
          <li>The weapon must be a simple or martial weapon.</li>
          </ul>
          <ul>
          <li>You must be proficient with it.</li>
          </ul>
          <ul>
          <li>It must lack the heavy and special properties.</li>
          </ul>`,
      },
      {
        name: 'Monasteric Tradition',
        level: 3,
        description: `
          <p>When you reach 3rd level, you commit yourself to a monastic tradition. Your tradition grants you features at 3rd level and again at 6th, 11th, and 17th level.</p>
            `,
      },
      {
        name: 'Deflect Missile',
        level: 3,
        description: `
        <p>Starting at 3rd level, you can use your reaction to deflect or catch the missile when you are hit by a ranged weapon attack. When you do so, the damage you take from the attack is reduced by 1d10 + your Dexterity modifier + your monk level.</p>
        <p>If you reduce the damage to 0, you can catch the missile if it is small enough for you to hold in one hand and you have at least one hand free. If you catch a missile in this way, you can spend 1 ki point to make a ranged attack with a range of 20/60 using the weapon or piece of ammunition you just caught, as part of the same reaction. You make this attack with proficiency, regardless of your weapon proficiencies, and the missile counts as a monk weapon for the attack.</p>
        `,
        ability: '',
      },
      {
        name: 'Ki-Fueled Attack (Optional)',
        level: 3,
        description: `
        <p>Also at 3rd level, if you spend 1 ki point or more as part of your action on your turn, you can make one attack with an unarmed strike or a monk weapon as a bonus action before the end of the turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
        <p>When you reach 4th level, and again at 8th, 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Slow Fall',
        level: 4,
        description: `
        <p>Beginning at 4th level, you can use your reaction when you fall to reduce any falling damage you take by an amount equal to five times your monk level.</p>
        `,
        ability: '',
      },
      {
        name: 'Quickened Healing',
        level: 4,
        description: `
        <p>Also at 4th level, as an action, you can spend 2 ki points and roll a Martial Arts die. You regain a number of hit points equal to the number rolled plus your proficiency bonus.</p>
        `,
        ability: '',
      },
      {
        name: 'Extra Attack',
        level: 5,
        description: `
        <p>Beginning at 5th level, you can attack twice, instead of once, whenever you take the Attack action on your turn.</p>
        `,
      },
      {
        name: 'Stunning Strike',
        level: 5,
        description: `
        <p>Starting at 5th level, you can interfere with the flow of ki in an opponent's body. When you hit another creature with a melee weapon attack, you can spend 1 ki point to attempt a stunning strike. The target must succeed on a Constitution saving throw or be stunned until the end of your next turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Focused Aim (Optional)',
        level: 5,
        description: `
        <p>Also at 5th level, when you miss with an attack roll, you can spend 1 to 3 ki points to increase your attack roll by 2 for each of these ki points you spend, potentially turning the miss into a hit.</p>
        `,
        ability: '',
      },
      {
        name: 'Ki-Empowered Strikes',
        level: 6,
        description: `
        <p>Starting at 6th level, your unarmed strikes count as magical for the purpose of overcoming resistance and immunity to nonmagical attacks and damage.</p>
        `,
      },
      {
        name: 'Evasion',
        level: 7,
        description: `
        <p>At 7th level, your instinctive agility lets you dodge out of the way of certain area effects, such as a blue dragon's lightning breath or a fireball spell. When you are subjected to an effect that allows you to make a Dexterity saving throw to take only half damage, you instead take no damage if you succeed on the saving throw, and only half damage if you fail.</p>
        `,
      },
      {
        name: 'Stillness of Mind',
        level: 7,
        description: `
        <p>Starting at 7th level, you can use your action to end one effect on yourself that is causing you to be charmed or frightened.</p>
        `,
        ability: '',
      },
      {
        name: 'Purity of Blood',
        level: 10,
        description: `
        <p>At 10th level, your mastery of the ki flowing through you makes you immune to disease and poison.</p>
        `,
      },
      {
        name: 'Tongue of the Sun and Moon',
        level: 13,
        description: `
        <p>Starting at 13th level, you learn to touch the ki of other minds so that you understand all spoken languages. Moreover, any creature that can understand a language can understand what you say.</p>
        `,
      },
      {
        name: 'Diamond Soul',
        level: 14,
        description: `
        <p>Beginning at 14th level, your mastery of ki grants you proficiency in all saving throws.</p>
        `,
      },
      {
        name: 'Timeless Body',
        level: 15,
        description: `
        <p>At 15th level, your ki sustains you so that you suffer none of the frailty of old age, and you can't be aged magically. You can still die of old age, however. In addition, you no longer need food or water.</p>
        `,
      },
      {
        name: 'Empty Body',
        level: 18,
        description: `
        <p>Beginning at 18th level, you can use your action to spend 4 ki points to become invisible for 1 minute. During that time, you also have resistance to all damage but force damage.</p>
        <p>Additionally, you can spend 8 ki points to cast the <em>astral projection</em> spell, without needing material components. When you do so, you can't take any other creatures with you.</p>
        `,
        ability: '',
      },
      {
        name: 'Perfect Self',
        level: 20,
        description: `
        <p>At 20th level, when you roll for initiative and have no ki points remaining, you regain 4 ki points.</p>
        `,
      },
    ],
  };

  public fighter: any = {
    title: 'Kämpfer',
    description: `
    <p>Fighters share an unparalleled mastery with weapons and armor, and a thorough knowledge of the skills of combat. They are well acquainted with death, both meting it out and staring it defiantly in the face.</p>
    <h4>Class Features</h4>
    <p>As a fighter, you gain the following class features.</p>

    <h4> Hit Points </h4>
    <b>Hit Dice:</b> 1d10 per fighter level <br>
    <b>Hit Points at 1st Level:</b> 10 + your Constitution modifier  <br>
    <b>Hit Points at Higher Levels:</b> 1d10 (or 6) + your Constitution modifier per fighter level after 1st  <br>
    <h4> Proficiencies</h4>
    <b>Armor:</b> All armor, shields  <br>
    <b>Weapons:</b> Simple weapons, martial weapons  <br>
    <b>Tools:</b> None  <br>
    <b>Saving Throws:</b> Strength, Constitution <br>
    <b>Skills:</b> Choose two skills from Acrobatics, Animal Handling, Athletics, History, Insight, Intimidation, Perception, and Survival <br>
    <h4> Equipment</h4>
    <ul>
    <li>(a) chain mail or (b) leather, longbow, and 20 arrows</li>
    <li>(a) a martial weapon and a shield or (b) two martial weapons</li>
    <li>(a) a light crossbow and 20 bolts or (b) two handaxes</li>
    <li>(a) a dungeoneer's pack or (b) an explorer's pack</li>
    `,
    features: [
      {
        name: 'Fighting Style',
        level: 1,
        description: `
      <p>You adopt a particular style of fighting as your specialty. Choose one of the following options. You can't take a Fighting Style option more than once, even if you later get to choose again.<p>
      <ul>
        <li> Archery (PHB). You gain a +2 bonus to attack rolls you make with ranged weapons.</li>
        <li> Blind Fighting (TCE). You have blindsight with a range of 10 feet. Within that range, you can effectively see anything that isn't behind total cover, even if you're blinded or in darkness. Moreover, you can see an invisible creature within that range, unless the creature successfully hides from you.</li>
        <li> Defense (PHB). While you are wearing armor, you gain a +1 bonus to AC.</li>
        <li> Dueling (PHB). When you are wielding a melee weapon in one hand and no other weapons, you gain a +2 bonus to damage rolls with that weapon.</li>
        <li> Great Weapon Fighting (PHB). When you roll a 1 or 2 on a damage die for an attack you make with a melee weapon that you are wielding with two hands, you can reroll the die and must use the new roll, even if the new roll is a 1 or a 2. The weapon must have the two-handed or versatile property for you to gain this benefit.</li>
        <li> Interception (TCE). When a creature you can see hits a target, other than you, within 5 feet of you with an attack, you can use your reaction to reduce the damage the target takes by 1d10 + your proficiency bonus (to a minimum of 0 damage). You must be wielding a shield or a simple or martial weapon to use this reaction.</li>
        <li> Protection (PHB). When a creature you can see attacks a target other than you that is within 5 feet of you, you can use your reaction to impose disadvantage on the attack roll. You must be wielding a shield.</li>
        <li> Superior Technique (TCE). You learn one maneuver of your choice from among those available to the Battle Master archetype. If a maneuver you use requires your target to make a saving throw to resist the maneuver's effects, the saving throw DC equals 8 + your proficiency bonus + your Strength or Dexterity modifier (your choice.)</li>
        <li> You gain one superiority die, which is a d6 (this die is added to any superiority dice you have from another source). This die is used to fuel your maneuvers. A superiority die is expended when you use it. You regain your expended superiority dice when you finish a short or long rest.</li>
        <li> Thrown Weapon Fighting (TCE). You can draw a weapon that has the thrown property as part of the attack you make with the weapon.</li>
        <li> In addition, when you hit with a ranged attack using a thrown weapon, you gain a +2 bonus to the damage roll.</li>
        <li> Two-Weapon Fighting (PHB). When you engage in two-weapon fighting, you can add your ability modifier to the damage of the second attack.</li>
        <li> Unarmed Fighting (TCE). Your unarmed strikes can deal bludgeoning damage equal to 1d6 + your Strength modifier on a hit. If you aren't wielding any weapons or a shield when you make the attack roll, the d6 becomes a d8.</li>
        <li> At the start of each of your turns, you can deal 1d4 bludgeoning damage to one creature grappled by you.</li>
        <li> Close Quarters Shooter (UA). When making a ranged attack while you are within 5 feet of a hostile creature, you do not have disadvantage on the attack roll. Your ranged attacks ignore half cover and three-quarters cover against targets within 30 feet of you. You have a +1 bonus to attack rolls on ranged attacks.</li>
        <li> Mariner (UA). As long as you are not wearing heavy armor or using a shield, you have a swimming speed and a climbing speed equal to your normal speed, and you gain a +1 bonus to armor class.</li>
        <li> Tunnel Fighter (UA). As a bonus action, you can enter a defensive stance that lasts until the start of your next turn. While in your defensive stance, you can make opportunity attacks without using your reaction, and you can use your reaction to make a melee attack against a creature that moves more than 5 feet while within your reach.</li>
      </ul>
      `,
      },
      {
        name: 'Second Wind',
        level: 1,
        description: `
          <p>You have a limited well of stamina that you can draw on to protect yourself from harm. On your turn, you can use a bonus action to regain hit points equal to 1d10 + your fighter level.</p>
          <p>Once you use this feature, you must finish a short or long rest before you can use it again.</p>
        `,
        ability: '',
      },
      {
        name: 'Action Surge',
        level: 2,
        description: `
          <p> Starting at 2nd level, you can push yourself beyond your normal limits for a moment. On your turn, you can take one additional action.</p>
          <p>Once you use this feature, you must finish a short or long rest before you can use it again. Starting at 17th level, you can use it twice before a rest, but only once on the same turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Martial Archetype',
        level: 3,
        description: `
          <p>At 3rd level, you choose an archetype that you strive to emulate in your combat styles and techniques. The archetype you choose grants you features at 3rd level and again at 7th, 10th, 15th, and 18th level.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
          <p>When you reach 4th level, and again at 6th, 8th, 12th, 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Extra Attack',
        level: 5,
        description: `
          <p>Beginning at 5th level, you can attack twice, instead of once, whenever you take the Attack action on your turn.<p>
          <p>The number of attacks increases to three when you reach 11th level in this class and to four when you reach 20th level in this class.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 6,
        description: `
          <p>When you reach 6th level, and again at 8th, 12th, 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 8,
        description: `
          <p>When you reach 8th level, and again at 12th, 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Indomitable',
        level: 9,
        description: `
          <p>Beginning at 9th level, you can reroll a saving throw that you fail. If you do so, you must use the new roll, and you can't use this feature again until you finish a long rest.</p>
        `,
      },
      {
        name: 'Extra Attack (x3)',
        level: 11,
        description: `
          <p>You can now attack three times whenever you take the Attack action on your turn.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 12,
        description: `
          <p>When you reach 12th level, and again at 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Indomitable (x2)',
        level: 13,
        description: `
          <p>You can reroll a saving throw that you fail. If you do so, you must use the new roll, and you can't use this feature again until you finish a long rest. You can now use this feature twice between long rests.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 14,
        description: `
          <p>When you reach 14th level, and again at 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 16,
        description: `
          <p>When you reach 16th level, and again at 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Indomitable (x3)',
        level: 17,
        description: `
          <p>You can reroll a saving throw that you fail. If you do so, you must use the new roll, and you can't use this feature again until you finish a long rest. You can now use this feature thrice between long rests.</p>
        `,
      },
      {
        name: 'Action Surge (x2)',
        level: 17,
        description: `
          <p>Starting at 17th level, you can use it twice before a rest, but only once on the same turn.</p>

        `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 19,
        description: `
         <p>When you reach 19th level you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Extra Attack (x4)',
        level: 20,
        description: `
          <p>You can now attack four times whenever you take the Attack action on your turn.</p>
        `,
      },
    ],
  };

  public barbarian: any = {
    title: 'Barbar',
    description: `
    <p>Barbarians are savage warriors who deal with their opponents through a combination of sheer brute force and terrifying rage. Their strength and ferocity make them well suited for melee combat. Barbarians are also able to wreak havoc on their enemies using unorthodox methods, such as throwing improvised weapons or even their own bodies.</p>
    <h4>Class Features</h4>
    <p>As a barbarian, you gain the following class features.</p>
    <h4> Hit Points</h4>
    <b>Hit Dice:</b> 1d12 per barbarian level <br>
    <b>Hit Points at 1st Level:</b> 12 + your Constitution modifier <br> 
    <b>Hit Points at Higher Levels:</b> 1d12 (or 7) + your Constitution modifier per barbarian level after 1st <br>
    <h4>Proficiencies</h4>
    <b>Armor:</b> Light armor, medium armor, shields <br>
    <b>Weapons:</b> Simple weapons, martial weapons <br>
    <b>Tools:</b> None <br>
    <b>Saving Throws:</b> Strength, Constitution <br>
    <b>Skills:</b> Choose two skills from Animal Handling, Athletics, Intimidation, Nature, Perception, and Survival

    <h4>Equipment</h4>
    <ul>
    <li> (a) a greataxe or (b) any martial melee weapon </li>
    <li> (a) two handaxes or (b) any simple weapon </li>
    <li> An explorer's pack and four javelins </li>
    </ul>
    `,
    features: [
      {
        name: 'Rage',
        level: 1,
        description: `
        <p>In battle, you fight with primal ferocity. On your turn, you can enter a rage as a bonus action.</p>
        <p>While raging, you gain the following benefits if you aren't wearing heavy armor:</p>
        <ul>
          <li> You have advantage on Strength checks and Strength saving throws. </li>
          <li> When you make a melee weapon attack using Strength, you gain a bonus to the damage roll that increases as you gain levels as a barbarian, as shown in the Rage Damage column of the Barbarian table. </li>  
          <li> You have resistance to bludgeoning, piercing, and slashing damage. </li>
          <li> If you are able to cast spells, you can't cast them or concentrate on them while raging. </li>
          <li> Your rage lasts for 1 minute. It ends early if you are knocked unconscious or if your turn ends and you haven't attacked a hostile creature since your last turn or taken damage since then. You can also end your rage on your turn as a bonus action. </li>
          <li> Once you have raged the number of times shown for your barbarian level in the Rages column of the Barbarian table, you must finish a long rest before you can rage again. </li>
        <ul>
          `,
        ability: '',
      },
      {
        name: 'Unarmored Defense',
        level: 1,
        description: `
          <p>While you are not wearing any armor, your Armor Class equals 10 + your Dexterity modifier + your Constitution modifier. You can use a shield and still gain this benefit. </p>
        `,
      },
      {
        name: 'Reckless Attack',
        level: 2,
        description: `
          <p>Starting at 2nd level, you can throw aside all concern for defense to attack with fierce desperation. When you make your first attack on your turn, you can decide to attack recklessly. Doing so gives you advantage on melee weapon attack rolls using Strength during this turn, but attack rolls against you have advantage until your next turn. </p>
        `,
        ability: '',
      },
      {
        name: 'Danger Sense',
        level: 2,
        description: `
          <p>At 2nd level, you gain an uncanny sense of when things nearby aren't as they should be, giving you an edge when you dodge away from danger. </p>
          <p>You have advantage on Dexterity saving throws against effects that you can see, such as traps and spells. To gain this benefit, you can't be blinded, deafened, or incapacitated. <p>
        `,
      },
      {
        name: 'Primal Path',
        level: 3,
        description: `
          <p>At 3rd level, you choose a path that shapes the nature of your rage. Choose the Path of the Berserker or the Path of the Totem Warrior, both detailed at the end of the class description. Your choice grants you features at 3rd level and again at 6th, 10th, and 14th levels. </p>
          `,
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
         <p> When you reach 4th level, and again at 6th, 8th, 12th, 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.  </p>
        `,
      },
      {
        name: 'Extra Attack',
        level: 5,
        description: `
          <p>Beginning at 5th level, you can attack twice, instead of once, whenever you take the Attack action on your turn.<p>
          <p>The number of attacks increases to three when you reach 11th level in this class and to four when you reach 20th level in this class.  </p>  
        `,
      },
      {
        name: 'Fast Movement',
        level: 5,
        description: `
          <p>Starting at 5th level, your speed increases by 10 feet while you aren't wearing heavy armor. </p>
        `,
      },
      {
        name: 'Feral Instinct',
        level: 7,
        description: `
          <p>By 7th level, your instincts are so honed that you have advantage on initiative rolls.</p>
         <p> Additionally, if you are surprised at the beginning of combat and aren't incapacitated, you can act normally on your first turn, but only if you enter your rage before doing anything else on that turn. </p>
        `,
      },
      {
        name: 'Brutal Critical',
        level: 9,
        description: `
          <p>Beginning at 9th level, you can roll one additional weapon damage die when determining the extra damage for a critical hit with a melee attack. </p>
          <p>This increases to two additional dice at 13th level and three additional dice at 17th level. </p>
        `,
      },
      {
        name: 'Relentless Rage',
        level: 11,
        description: `
          <p>Starting at 11th level, your rage can keep you fighting despite grievous wounds. If you drop to 0 hit points while you're raging and don't die outright, you can make a DC 10 Constitution saving throw. If you succeed, you drop to 1 hit point instead. </p>
          <p>Each time you use this feature after the first, the DC increases by 5. When you finish a short or long rest, the DC resets to 10. </p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 12,
        description: `
          <p>When you reach 12th level, and again at 14th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
        `,
      },
      {
        name: 'Persistent Rage',
        level: 15,
        description: `
          <p>Beginning at 15th level, your rage is so fierce that it ends early only if you fall unconscious or if you choose to end it. <p>
        `,
      },
      {
        name: 'Indomitable Might',
        level: 18,
        description: `
          <p>Beginning at 18th level, if your total for a Strength check is less than your Strength score, you can use that score in place of the total.</p>
        `,
      },
      {
        name: 'Primal Champion',
        level: 20,
        description: `
          <p>At 20th level, you embody the power of the wilds. Your Strength and Constitution scores increase by 4. Your maximum for those scores is now 24. </p>
        `,
      },
    ],
  };

  public ranger: any = {
    title: 'Waldläufer',
    description: `
    <p>Rangers are skilled stalkers and hunters who make their home in the woods. Their martial skill is nearly the equal of the fighter, but they lack the latter's dedication to the craft of fighting. Instead, the ranger focuses his skills and training on a specific enemy—a type of creature he bears a vengeful grudge against and hunts above all others.</p>
    <h4>Class Features</h4>
    <p>As a ranger, you gain the following class features.</p>
    <h4> Hit Points</h4>
    <b>Hit Dice:</b> 1d10 per ranger level <br>
    <b>Hit Points at 1st Level:</b> 10 + your Constitution modifier <br>
    <b>Hit Points at Higher Levels:</b> 1d10 (or 6) + your Constitution modifier per ranger level after 1st <br>
    <h4> Proficiencies</h4>
    <b>Armor:</b> Light armor, medium armor, shields <br>
    <b>Weapons:</b> Simple weapons, martial weapons <br>
    <b>Tools:</b> None <br>
    <b>Saving Throws:</b> Strength, Dexterity <br>
    <b>Skills:</b> Choose three from Animal Handling, Athletics, Insight, Investigation, Nature, Perception, Stealth, and Survival <br>
    <h4> Equipment</h4>
    <ul>
    <li> (a) scale mail or (b) leather armor </li>
    <li> (a) two shortswords or (b) two simple melee weapons </li>
    <li> (a) a dungeoneer's pack or (b) an explorer's pack </li>
    <li> A longbow and a quiver of 20 arrows </li>
    </ul>
    `,
    features: [
      {
        name: 'Favored Enemy',
        level: 1,
        description: `
        <p>Beginning at 1st level, you have significant experience studying, tracking, hunting, and even talking to a certain type of enemy.</p>
        <p>Choose a type of favored enemy: aberrations, beasts, celestials, constructs, dragons, elementals, fey, fiends, giants, monstrosities, oozes, plants, or undead. Alternatively, you can select two races of humanoid (such as gnolls and orcs) as favored enemies.</p>
        <p>You have advantage on Wisdom (Survival) checks to track your favored enemies, as well as on Intelligence checks to recall information about them.</p>
        <p>When you gain this feature, you also learn one language of your choice that is spoken by your favored enemies, if they speak one at all.</p>
        <p>You choose one additional favored enemy, as well as an associated language, at 6th and 14th level. As you gain levels, your choices should reflect the types of monsters you have encountered on your adventures.</p>
        `,
        ability: '',
      },
      {
        name: 'Favored Foe (Optional)',
        level: 1,
        description: `
        <p>This 1st-level feature replaces the Favored Enemy feature and works with the Foe Slayer feature. You gain no benefit from the replaced feature and don't qualify for anything in the game that requires it.</p>
      <p>When you hit a creature with an attack roll, you can call on your mystical bond with nature to mark the target as your favored enemy for 1 minute or until you lose your concentration (as if you were concentrating on a spell).</p>
      <p>The first time on each of your turns that you hit the favored enemy and deal damage to it, including when you mark it, you increase that damage by 1d4.</p>
      <p>You can use this feature to mark a favored enemy a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
      <p>This feature's extra damage increases when you reach certain levels in this class: to 1d6 at 6th level and to 1d8 at 14th level.</p>
      `,
        ability: '',
      },
      {
        name: 'Natural Explorer',
        level: 1,
        description: `
        <p>Also at 1st level, you are particularly familiar with one type of natural environment and are adept at traveling and surviving in such regions. Choose one type of favored terrain: arctic, coast, desert, forest, grassland, mountain, swamp, or the Underdark. When you make an Intelligence or Wisdom check related to your favored terrain, your proficiency bonus is doubled if you are using a skill that you’re proficient in.</p>
        <p>While traveling for an hour or more in your favored terrain, you gain the following benefits:</p>
        <ul>
        <li>Difficult terrain doesn’t slow your group’s travel.</li>
        <li>Your group can’t become lost except by magical means.</li>
        <li>Even when you are engaged in another activity while traveling (such as foraging, navigating, or tracking), you remain alert to danger.</li>
        <li>If you are traveling alone, you can move stealthily at a normal pace.</li>
        <li>When you forage, you find twice as much food as you normally would.</li>
        <li>While tracking other creatures, you also learn their exact number, their sizes, and how long ago they passed through the area.</li>
        </ul>
        <p>You hoose additional favored terrain types at 6th and 10th level.</p>
      `,
      },
      {
        name: 'Deft Explorer (Optional)',
        level: 1,
        description: `
        <p>This 1st-level feature replaces the Natural Explorer feature. You gain no benefit from the replaced feature and don't qualify for anything in the game that requires it.</p>
        <p>You are an unsurpassed explorer and survivor, both in the wilderness and in dealing with others on your travels. You gain the Canny benefit below, and you gain an additional benefit when you reach 6th level and 10th level in this class.</p>
        <h6 id="toc8"><span>Canny (1st Level)</span></h6>
        <p>Choose one of your skill proficiencies. Your proficiency bonus is doubled for any ability check you make using the chosen skill.</p>
        <p>You can also speak, read, and write 2 additional languages of your choice.</p>
        <h6 id="toc9"><span>Roving (6th Level)</span></h6>
        <p>Your walking speed increases by 5, and you gain a climbing speed and a swimming speed equal to your walking speed.</p>
        <h6 id="toc10"><span>Tireless (10th Level)</span></h6>
        <p>As an action, you can give yourself a number of temporary hit points equal to 1d8 + your Wisdom modifier (minimum of 1 temporary hit point). You can use this action a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
        <p>In addition, whenever you finish a short rest, your exhaustion level, if any, is decreased by 1.</p>`,
      },
      {
        name: 'Fighting Style',
        level: 2,
        description: `
        <p>At 2nd level, you adopt a particular style of fighting as your specialty. Choose one of the following options. You can't take a Fighting Style option more than once, even if you later get to choose again.</p>
        <ul>
        <li><strong>Archery.</strong> You gain a +2 bonus to attack rolls you make with ranged weapons.</li>
        </ul>
        <ul>
        <li><strong>Blind Fighting.</strong> You have blind sight with a range of 10 feet. Within that range, you can effectively see anything that isn't behind total cover, even if you're blinded or in darkness. Moreover, you can see an invisible creature within that range, unless the creature successfully hides from you.</li>
        </ul>
        <ul>
        <li><strong>Defense.</strong> While you are wearing armor, you gain a +1 bonus to AC.</li>
        </ul>
        <ul>
        <li><strong>Druidic Warrior.</strong> You learn two cantrips of your choice from the Druid spell list. They count as ranger spells for you, and Wisdom is your spellcasting ability for them. Whenever you gain a level in this class, you can replace one of these cantrips with another cantrip from the Druid spell list.</li>
        </ul>
        <ul>
        <li><strong>Dueling.</strong> When you are wielding a melee weapon in one hand and no other weapons, you gain a +2 bonus to damage rolls with that weapon.</li>
        </ul>
        <ul>
        <li><strong>Thrown Weapon Fighting.</strong> You can draw a weapon that has the thrown property as part of the attack you make with the weapon.
        <ul>
        <li>In addition, when you hit with a ranged attack using a thrown weapon, you gain a +2 bonus to the damage roll.</li>
        </ul>
        </li>
        </ul>
        <ul>
        <li><strong>Two-Weapon Fighting.</strong> When you engage in two-weapon fighting, you can add your ability modifier to the damage of the second attack.</li>
        </ul>
        <ul>
        <li><strong>Close Quarters Shooter (UA).</strong> When making a ranged attack while you are within 5 feet of a hostile creature, you do not have disadvantage on the attack roll. Your ranged attacks ignore half cover and three-quarters cover against targets within 30 feet of you. You have a +1 bonus to attack rolls on ranged attacks.</li>
        </ul>
        <ul>
        <li><strong>Interception (UA).</strong> When a creature you can see hits a target that is within 5 feet of you with an attack, you can use your reaction to reduce the damage the target takes by 1d10 + your proficiency bonus (to a minimum of 0 damage). You must be wielding a shield or a simple or martial weapon to use this reaction.</li>
        </ul>
        <ul>
        <li><strong>Mariner (UA).</strong> As long as you are not wearing heavy armor or using a shield, you have a swimming speed and a climbing speed equal to your normal speed, and you gain a +1 bonus to armor class.</li>
        </ul>
        <ul>
        <li><strong>Tunnel Fighter (UA).</strong> As a bonus action, you can enter a defensive stance that lasts until the start of your next turn. While in your defensive stance, you can make opportunity attacks without using your reaction, and you can use your reaction to make a melee attack against a creature that moves more than 5 feet while within your reach.</li>
        </ul>
        <ul>
        <li><strong>Unarmed Fighting (UA).</strong> Your unarmed strikes can deal bludgeoning damage equal to 1d6 + your Strength modifier. If you strike with two free hands, the d6 becomes a d8.
        <ul>
        <li>When you successfully start a grapple, you can deal 1d4 bludgeoning damage to the grappled creature. Until the grapple ends, you can also deal this damage to the creature whenever you hit it with a melee attack.</li>
        </ul>
        </li>
        </ul>`,
      },
      {
        name: 'Spellcasting',
        level: 2,
        description: `
        <p>By the time you reach 2nd level, you have learned to use the magical essence of nature to cast spells, much as a druid does.</p>
        <h6 id="toc13"><span>Spell Slots</span></h6>
        <p>The Ranger table shows how many spell slots you have to cast your ranger spells of 1st level and higher. To cast one of these spells, you must expend a slot of the spell's level or higher. You regain all expended spell slots when you finish a long rest.</p>
        <p>For example, if you know the 1st-level spell Animal Friendship and have a 1st-level and a 2nd-level spell slot available, you can cast Animal Friendship using either slot.</p>
        <h6 id="toc14"><span>Spells Known of 1st Level and Higher</span></h6>
        <p>You know two 1st-level spells of your choice from the ranger spell list.</p>
        <p>The Spells Known column of the Ranger table shows when you learn more ranger spells of your choice. Each of these spells must be of a level for which you have spell slots. For instance, when you reach 5th level in this class, you can learn one new spell of 1st or 2nd level.</p>
        <p>Additionally, when you gain a level in this class, you can choose one of the ranger spells you know and replace it with another spell from the ranger spell list, which also must be of a level for which you have spell slots.</p>
        <h6 id="toc15"><span>Spellcasting Ability</span></h6>
        <p>Wisdom is your spellcasting ability for your ranger spells, since your magic draws on your attunement to nature. You use your Wisdom whenever a spell refers to your spellcasting ability. In addition, you use your Wisdom modifier when setting the saving throw DC for a ranger spell you cast and when making an attack roll with one.</p>
        <p><strong>Spell save DC</strong> = 8 + your proficiency bonus + your Wisdom modifier</p>
        <p><strong>Spell attack modifier</strong> = your proficiency bonus + your Wisdom modifier</p>
        <h6 id="toc16"><span>Spellcasting Focus (Optional)</span></h6>
        <p>At 2nd level, you can use a druidic focus as a spellcasting focus for your ranger spells. A druidic focus might be a sprig of mistletoe or holly, a wand or rod made of yew or another special wood, a staff drawn whole from a living tree, or an object incorporating feathers, fur, bones, and teeth from sacred animals.</p>
        `,
      },
      {
        name: 'Primeval Awareness',
        level: 3,
        description: `
        <p>Beginning at 3rd level, you can use your action and expend one ranger spell slot to focus your awareness on the region around you. For 1 minute per level of the spell slot you expend, you can sense whether the following types of creatures are present within 1 mile of you (or within up to 6 miles if you are in your favored terrain): aberrations, celestials, dragons, elementals, fey, fiends, and undead. This feature doesn’t reveal the creatures’ location or number.</p>
        `,
        ability: '',
      },
      {
        name: 'Ranger Conclave',
        level: 3,
        description: `
        <p>At 3rd level, you choose to emulate the ideals and training of a ranger conclave. Your choice grants you features at 3rd level and again at 7th, 11th, and 15th level.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
        <p>When you reach 4th level, and again at 8th, 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Martial Versatility (Optional)',
        level: 4,
        description: `
        <p>Whenever you reach a level in this class that grants the Ability Score Improvement feature, you can replace a fighting style you know with another fighting style available to rangers. This replacement represents a shift of focus in your martial practice.</p>
      `,
      },
      {
        name: 'Extra Attack',
        level: 5,
        description: `
        <p>Beginning at 5th level, you can attack twice, instead of once, whenever you take the Attack action on your turn.</p>`,
      },
      {
        name: "Land's Stride",
        level: 8,
        description: `
        <p>Starting at 8th level, moving through nonmagical difficult terrain costs you no extra movement. You can also pass through nonmagical plants without being slowed by them and without taking damage from them if they have thorns, spines, or a similar hazard.</p>
        <p>In addition, you have advantage on saving throws against plants that are magically created or manipulated to impede movement, such as those created by the Entangle spell.</p>
        `,
      },
      {
        name: 'Hide in Plain Sight',
        level: 10,
        description: `
        <p>Starting at 10th level, you can spend 1 minute creating camouflage for yourself. You must have access to fresh mud, dirt, plants, soot, and other naturally occurring materials with which to create your camouflage.</p>
        <p>Once you are camouflaged in this way, you can try to hide by pressing yourself up against a solid surface, such as a tree or wall, that is at least as tall and wide as you are. You gain a +10 bonus to Dexterity (Stealth) checks as long as you remain there without moving or taking actions. Once you move or take an action or a reaction, you must camouflage yourself again to gain this benefit.</p>
        `,
        ability: '',
      },
      {
        name: 'Natures Veil (Optional)',
        level: 10,
        description: `
        <p>This 10th-level feature replaces the Hide in Plain Sight feature. You gain no benefit from the replaced feature and don't qualify for anything in the game that requires it.</p>
        <p>You draw on the powers of nature to hide yourself from view briefly. As a bonus action, you can magically become invisible, along with any equipment you are wearing or carrying, until the start of your next turn.</p>
        <p>You can use this feature a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
        `,
        ability: '',
      },
      {
        name: 'Vanish',
        level: 14,
        description: `
        <p>Starting at 14th level, you can use the Hide action as a bonus action on your turn. Also, you can't be tracked by nonmagical means, unless you choose to leave a trail.</p>
        `,
        ability: '',
      },
      {
        name: 'Feral Senses',
        level: 18,
        description: `
        <p>At 18th level, you gain preternatural senses that help you fight creatures you can't see. When you attack a creature you can't see, your inability to see it doesn't impose disadvantage on your attack rolls against it.</p>
        <p>You are also aware of the location of any invisible creature within 30 feet of you, provided that the creature isn't hidden from you and you aren't blinded or deafened.</p>
        `,
      },
      {
        name: 'Foe Slayer',
        level: 20,
        description: `
        <p>At 20th level, you become an unparalleled hunter of your enemies. Once on each of your turns, you can add your Wisdom modifier to the attack roll or the damage roll of an attack you make against one of your favored enemies. You can choose to use this feature before or after the roll, but before any effects of the roll are applied.</p>
      `,
      },
    ],
  };

  public cleric: any = {
    title: 'Cleric',
    description: `
    <p>Clerics are intermediaries between the mortal world and the distant planes of the gods. As varied as the gods they serve, clerics strive to embody the handiwork of their deities. No ordinary priest, a cleric is imbued with divine magic.</p>
    <h4>Class Features</h4>
    <p>As a cleric, you gain the following class features.</p>
    <h4> Hit Points</h4>
    <b>Hit Dice:</b> 1d8 per cleric level <br>
    <b>Hit Points at 1st Level:</b> 8 + your Constitution modifier<br>
    <b>Hit Points at Higher Levels:</b> 1d8 (or 5) + your Constitution modifier per cleric level after 1st<br>
    <h4> Proficiencies</h4>
    <b>Armor:</b> Light armor, medium armor, shields<br>
    <b>Weapons:</b> Simple weapons<br>
    <b>Tools:</b> None<br>
    <b>Saving Throws:</b> Wisdom, Charisma<br>
    <b>Skills:</b> Choose two from History, Insight, Medicine, Persuasion, and Religion<br>
    <h4> Equipment</h4>
    <ul>
    <li> (a) a mace or (b) a warhammer (if proficient)</li>
    <li> (a) scale mail, (b) leather armor, or (c) chain mail (if proficient)</li>
    <li> (a) a light crossbow and 20 bolts or (b) any simple weapon</li>
    <li> (a) a priest's pack or (b) an explorer's pack</li>
    <li> A shield and a holy symbol</li>
    <ul>
    `,
    features: [
      {
        name: 'Spellcasting',
        level: 1,
        description: `
        <b>Cantrips</b>
        <p>At 1st level, you know three cantrips of your choice from the cleric spell list. You learn additional cleric cantrips of your choice at higher levels, as shown in the Cantrips Known column of the Cleric table.</p>
        <b>Spell Slots</b>
        <p>The Cleric table shows how many spell slots you have to cast your cleric spells of 1st level and higher. To cast one of these spells, you must expend a slot of the spell's level or higher. You regain all expended spell slots when you finish a long rest.</p>
        <p>You prepare the list of cleric spells that are available for you to cast, choosing from the cleric spell list. When you do so, choose a number of cleric spells equal to your Wisdom modifier + your cleric level (minimum of one spell). The spells must be of a level for which you have spell slots.</p>
        <p>For example, if you are a 3rd-level cleric, you have four 1st-level and two 2nd-level spell slots. With a Wisdom of 16, your list of prepared spells can include six spells of 1st or 2nd level, in any combination. If you prepare the 1st-level spell Cure Wounds, you can cast it using a 1st-level or 2nd-level slot. Casting the spell doesn't remove it from your list of prepared spells.</p>
        <p>You can change your list of prepared spells when you finish a long rest. Preparing a new list of cleric spells requires time spent in prayer and meditation: at least 1 minute per spell level for each spell on your list.</p>
        <h4>Spellcasting Ability</h4>
        <p>Wisdom is your spellcasting ability for your cleric spells. The power of your spells comes from your devotion to your deity. You use your Wisdom whenever a cleric spell refers to your spellcasting ability. In addition, you use your Wisdom modifier when setting the saving throw DC for a cleric spell you cast and when making an attack roll with one.</p>
        <b>Spell save DC:</b> 8 + your proficiency bonus + your Wisdom modifier<br>
        <b>Spell attack modifier:</b> your proficiency bonus + your Wisdom modifier<br>
        `,
      },
      {
        name: 'Divine Domain',
        level: 1,
        description: `
          <p>At 1st level, you choose a domain shaped by your choice of Deity and the gifts they grant you. Your choice grants you domain spells and other features when you choose it at 1st level. It also grants you additional ways to use Channel Divinity when you gain that feature at 2nd level, and additional benefits at 6th, 8th, and 17th levels.</p>
          `,
      },
      {
        name: 'Channel Divinity',
        level: 2,
        description: `
          <p>At 2nd level, you gain the ability to channel divine energy directly from your deity, using that energy to fuel magical effects. You start with two such effects: Turn Undead and an effect determined by your domain. Some domains grant you additional effects as you advance in levels, as noted in the domain description.</p>
          <p>When you use your Channel Divinity, you choose which effect to create. You must then finish a short or long rest to use your Channel Divinity again.</p>
          <p>Some Channel Divinity effects require saving throws. When you use such an effect from this class, the DC equals your cleric spell save DC.</p>
          <p>Beginning at 6th level, you can use your Channel Divinity twice between rests, and beginning at 18th level, you can use it three times between rests. When you finish a short or long rest, you regain your expended uses.</p>
          `,
      },
      {
        name: 'Channel Divinity Turn Undead',
        level: 2,
        description: `
          <p>As an action, you present your holy symbol and speak a prayer censuring the undead. Each undead that can see or hear you within 30 feet of you must make a Wisdom saving throw. If the creature fails its saving throw, it is turned for 1 minute or until it takes any damage.</p>
          <p>A turned creature must spend its turns trying to move as far away from you as it can, and it can't willingly move to a space within 30 feet of you. It also can't take reactions. For its action, it can use only the Dash action or try to escape from an effect that prevents it from moving. If there's nowhere to move, the creature can use the Dodge action.</p>
          `,
        ability: '',
      },
      {
        name: 'Harness Divine Power',
        level: 2,
        description: `
          <p>At 2nd level, you can expend a use of your Channel Divinity to fuel your spells. As a bonus action, you touch your holy symbol, utter a prayer, and regain one expended spell slot, the level of which can be no higher than half your proficiency bonus (rounded up). The number of times you can use this feature is based on the level you've reached in this class: 2nd level, once; 6th level, twice; and 18th level, thrice. You regain all expended uses when you finish a long rest.<p>
          `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
          <p>When you reach 4th level, and again at 8th, 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
      {
        name: 'Destroy Undead',
        level: 5,
        description: `
          <p>Starting at 5th level, when an undead fails its saving throw against your Turn Undead feature, the creature is instantly destroyed if its challenge rating is at or below a certain threshold, as shown in the Cleric table above.</p>`,
      },
      {
        name: 'Blessed Strikes',
        level: 8,
        description: `
          <p>Replaces the Divine Strike or Potent Spellcasting feature</p>
          <p>When you reach 8th level, you are blessed with divine might in battle. When a creature takes damage from one of your cantrips or weapon attacks, you can also deal 1d8 radiant damage to that creature. Once you deal this damage, you can't use this feature again until the start of your next turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 8,
        description: `
          <p>When you reach 8th level, and again at 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
      {
        name: 'Divine Intervention',
        level: 10,
        description: `
          <p>Beginning at 10th level, you can call on your deity to intervene on your behalf when your need is great.</p>
          <p>Imploring your deity's aid requires you to use your action. Describe the assistance you seek, and roll percentile dice. If you roll a number equal to or lower than your cleric level, your deity intervenes. The GM chooses the nature of the intervention; the effect of any cleric spell or cleric domain spell would be appropriate.</p>
          <p>If your deity intervenes, you can't use this feature again for 7 days. Otherwise, you can use it again after you finish a long rest.</p>
          <p>At 20th level, your call for intervention succeeds automatically, no roll required.</p>
        `,
        ability: '',
      },
      {
        name: 'Ability Score Improvement',
        level: 12,
        description: `
          <p>When you reach 4th level, and again at 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
      {
        name: 'Ability Score Improvement',
        level: 16,
        description: `
          <p>When you reach 4th level, and again at 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
      {
        name: 'Ability Score Improvement',
        level: 19,
        description: `
          <p>When you reach 19th level you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature. </p>
          `,
      },
    ],
  };

  public paladin: any = {
    title: 'Paladin',
    description: `
    <p>Paladins are the ultimate champions of good, using their holy magic to protect the innocent and spread justice. They are often found in the thick of battle, smiting evil and saving the lives of their allies.</p>
    <h4>Class Features</h4>
    <p>As a paladin, you gain the following class features.</p>
    <h4> Hit Points</h4>
    <b>Hit Dice:</b> 1d10 per paladin level <br>
    <b>Hit Points at 1st Level:</b> 10 + your Constitution modifier <br>
    <b>Hit Points at Higher Levels:</b> 1d10 (or 6) + your Constitution modifier per paladin level after 1st <br>
    <h4> Proficiencies</h4>
    <b>Armor:</b> All armor, shields <br>
    <b>Weapons:</b> Simple weapons, martial weapons <br>
    <b>Tools:</b> None <br>
    <b>Saving Throws:</b> Wisdom, Charisma <br>
    <b>Skills:</b> Choose two from Athletics, Insight, Intimidation, Medicine, Persuasion, and Religion <br>
    <h4> Equipment</h4>
    <ul>
    <li> (a) a martial weapon and a shield or (b) two martial weapons </li>
    <li> (a) five javelins or (b) any simple melee weapon </li>
    <li> (a) a priest's pack or (b) an explorer's pack </li>
    <li> Chain mail and a holy symbol </li>
    </ul>
    `,
    features: [
      {
        name: 'Divine Sense',
        level: 1,
        description: `
        <p>The presence of strong evil registers on your senses like a noxious odor, and powerful good rings like heavenly music in your ears. As an action, you can open your awareness to detect such forces. Until the end of your next turn, you know the location of any celestial, fiend, or undead within 60 feet of you that is not behind total cover. You know the type (celestial, fiend, or undead) of any being whose presence you sense, but not its identity (the vampire Count Strahd von Zarovich, for instance). Within the same radius, you also detect the presence of any place or object that has been consecrated or desecrated, as with the hallow spell.</p>
        <p>You can use this feature a number of times equal to 1 + your Charisma modifier. When you finish a long rest, you regain all expended uses.</p>
        `,
        ability: '',
      },
      {
        name: 'Lay on Hands',
        level: 1,
        description: `
        <p>Your blessed touch can heal wounds. You have a pool of healing power that replenishes when you take a long rest. With that pool, you can restore a total number of hit points equal to your paladin level × 5.</p>
        <p>As an action, you can touch a creature and draw power from the pool to restore a number of hit points to that creature, up to the maximum amount remaining in your pool.</p>
        <p>Alternatively, you can expend 5 hit points from your pool of healing to cure the target of one disease or neutralize one poison affecting it. You can cure multiple diseases and neutralize multiple poisons with a single use of Lay on Hands, expending hit points separately for each one.</p>
        <p>This feature has no effect on undead and constructs.</p>
        `,
        ability: '',
      },
      {
        name: 'Fighting Style',
        level: 2,
        description: `
        <p>Starting at 2nd level, you adopt a particular style of fighting as your specialty. Choose one of the following options. You can't take a Fighting Style option more than once, even if you later get to choose again.</p>
        <ul>
        <li><strong>Blessed Warrior.</strong> You learn two cantrips of your choice from the cleric spell list. They count as paladin spells for you, and Charisma is your spellcasting ability for them. Whenever you gain a level in this class, you can replace one of these cantrips with another cantrip from the cleric spell list.</li>
        </ul>
        <ul>
        <li><strong>Blind Fighting.</strong> You have blindsight with a range of 10 feet. Within that range, you can effectively see anything that isn't behind total cover, even if you're blinded or in darkness. Moreover, you can see an invisible creature within that range, unless the creature successfully hides from you.</li>
        </ul>
        <ul>
        <li><strong>Defense.</strong> While you are wearing armor, you gain a +1 bonus to AC.</li>
        </ul>
        <ul>
        <li><strong>Dueling.</strong> When you are wielding a melee weapon in one hand and no other weapons, you gain a +2 bonus to damage rolls with that weapon.</li>
        </ul>
        <ul>
        <li><strong>Great Weapon Fighting.</strong> When you roll a 1 or 2 on a damage die for an attack you make with a melee weapon that you are wielding with two hands, you can reroll the die and must use the new roll, even if the new roll is a 1 or a 2. The weapon must have the two-handed or versatile property for you to gain this benefit.</li>
        </ul>
        <ul>
        <li><strong>Interception.</strong> When a creature you can see hits a target, other than you, within 5 feet of you with an attack, you can use your reaction to reduce the damage the target takes by 1d10 + your proficiency bonus (to a minimum of 0 damage). You must be wielding a shield or a simple or martial weapon to use this reaction.</li>
        </ul>
        <ul>
        <li><strong>Protection.</strong> When a creature you can see attacks a target other than you that is within 5 feet of you, you can use your reaction to impose disadvantage on the attack roll. You must be wielding a shield.</li>
        </ul>
        <ul>
        <li><strong>Close Quarters Shooter (UA).</strong> When making a ranged attack while you are within 5 feet of a hostile creature, you do not have disadvantage on the attack roll. Your ranged attacks ignore half cover and three-quarters cover against targets within 30 feet of you. You have a +1 bonus to attack rolls on ranged attacks.</li>
        </ul>
        <ul>
        <li><strong>Mariner (UA).</strong> As long as you are not wearing heavy armor or using a shield, you have a swimming speed and a climbing speed equal to your normal speed, and you gain a +1 bonus to armor class.</li>
        </ul>
        <ul>
        <li><strong>Thrown Weapon Fighting (UA).</strong> You can draw a weapon that has the thrown property as part of the attack you make with the weapon.
        <ul>
        <li>In addition, when you hit with a ranged attack using a thrown weapon, you gain a +1 bonus to the damage roll.</li>
        </ul>
        </li>
        </ul>
        <ul>
        <li><strong>Tunnel Fighter (UA).</strong> As a bonus action, you can enter a defensive stance that lasts until the start of your next turn. While in your defensive stance, you can make opportunity attacks without using your reaction, and you can use your reaction to make a melee attack against a creature that moves more than 5 feet while within your reach.</li>
        </ul>
        <ul>
        <li><strong>Unarmed Fighting (UA).</strong> Your unarmed strikes can deal bludgeoning damage equal to 1d6 + your Strength modifier. If you strike with two free hands, the d6 becomes a d8.
        <ul>
        <li>When you successfully start a grapple, you can deal 1d4 bludgeoning damage to the grappled creature. Until the grapple ends, you can also deal this damage to the creature whenever you hit it with a melee attack.</li>
        </ul>
        </li>
        </ul>
        `,
      },
      {
        name: 'Spellcasting',
        level: 2,
        description: `
        <p>By 2nd level, you have learned to draw on divine magic through meditation and prayer to cast spells as a cleric does.</p>
        <b id="toc8"><span>Preparing and Casting Spells</span></b>
        <p>The Paladin table shows how many spell slots you have to cast your paladin spells. To cast one of your paladin spells of 1st level or higher, you must expend a slot of the spell's level or higher. You regain all expended spell slots when you finish a long rest.</p>
        <p>You prepare the list of paladin spells that are available for you to cast, choosing from the paladin spell list. When you do so, choose a number of paladin spells equal to your Charisma modifier + half your paladin level, rounded down (minimum of one spell). The spells must be of a level for which you have spell slots.</p>
        <p>For example, if you are a 5th-level paladin, you have four 1st-level and two 2nd-level spell slots. With a Charisma of 14, your list of prepared spells can include four spells of 1st or 2nd level, in any combination. If you prepare the 1st-level spell Cure Wounds, you can cast it using a 1st-level or a 2nd-level slot. Casting the spell doesn't remove it from your list of prepared spells.</p>
        <p>You can change your list of prepared spells when you finish a long rest. Preparing a new list of paladin spells requires time spent in prayer and meditation: at least 1 minute per spell level for each spell on your list.</p>
        <b id="toc9"><span>Spellcasting Ability</span></b>
        <p>Charisma is your spellcasting ability for your paladin spells, since their power derives from the strength of your convictions. You use your Charisma whenever a spell refers to your spellcasting ability. In addition, you use your Charisma modifier when setting the saving throw DC for a paladin spell you cast and when making an attack roll with one.</p>
        <p><strong>Spell save DC</strong> = 8 + your proficiency bonus + your Charisma modifier</p>
        <p><strong>Spell attack modifier</strong> = your proficiency bonus + your Charisma modifier</p>
        <b id="toc10"><span>Spellcasting Focus</span></b>
        <p>You can use a holy symbol as a spellcasting focus for your paladin spells.</p>
        `,
      },
      {
        name: 'Divine Smite',
        level: 2,
        description: `
        <p>Starting at 2nd level, when you hit a creature with a melee weapon attack, you can expend one spell slot to deal radiant damage to the target, in addition to the weapon's damage. The extra damage is 2d8 for a 1st-level spell slot, plus 1d8 for each spell level higher than 1st, to a maximum of 5d8. The damage increases by 1d8 if the target is an undead or a fiend, to a maximum of 6d8.</p>
        `,
      },
      {
        name: 'Divine Health',
        level: 3,
        description: `
        <p>By 3rd level, the divine magic flowing through you makes you immune to disease.</p>
        `,
      },
      {
        name: 'Sacred Oath',
        level: 3,
        description: `
        <p>When you reach 3rd level, you swear the oath that binds you as a paladin forever. Up to this time you have been in a preparatory stage, committed to the path but not yet sworn to it. Your choice grants you features at 3rd level and again at 7th, 15th, and 20th level. Those features include oath spells and the Channel Divinity feature.</p>
        <h6 id="toc14"><span>Oath Spells</span></h6>
        <p>Each oath has a list of associated spells. You gain access to these spells at the levels specified in the oath description. Once you gain access to an oath spell, you always have it prepared. Oath spells don't count against the number of spells you can prepare each day.</p>
        <p>If you gain an oath spell that doesn't appear on the paladin spell list, the spell is nonetheless a paladin spell for you.</p>
        <h6 id="toc15"><span>Channel Divinity</span></h6>
        <p>Your oath allows you to channel divine energy to fuel magical effects. Each Channel Divinity option provided by your oath explains how to use it.</p>
        <p>When you use your Channel Divinity, you choose which option to use. You must then finish a short or long rest to use your Channel Divinity again.</p>
        <p>Some Channel Divinity effects require saving throws. When you use such an effect from this class, the DC equals your paladin spell save DC.</p>
        `,
      },
      {
        name: 'Harness Divine Power',
        level: 3,
        description: `
        <p>Also at 3rd level, you can expend a use of your Channel Divinity to fuel your spells. As a bonus action, you touch your holy symbol, utter a prayer, and regain one expended spell slot, the level of which can be no higher than half your proficiency bonus (rounded up). The number of times you can use this feature is based on the level you've reached in this class: 3rd level, once; 7th level, twice; and 15th level, thrice. You regain all expended uses when you finish a long rest.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
        <p>When you reach 4th level, and again at 8th, 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Martial Versatility (Optional)',
        level: 4,
        description: `
        <p>Whenever you reach a level in this class that grants the Ability Score Improvement feature, you can replace a fighting style you know with another fighting style available to paladins. This replacement represents a shift of focus in your martial practice.</p>
        `,
      },
      {
        name: 'Extra Attack',
        level: 5,
        description: `
        <p>Beginning at 5th level, you can attack twice, instead of once, whenever you take the Attack action on your turn.</p>
        `,
      },
      {
        name: 'Aura of Protection',
        level: 6,
        description: `
        <p>Starting at 6th level, whenever you or a friendly creature within 10 feet of you must make a saving throw, the creature gains a bonus to the saving throw equal to your Charisma modifier (with a minimum bonus of +1). You must be conscious to grant this bonus.</p>
        <p>At 18th level, the range of this aura increases to 30 feet.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 8,
        description: `
        <p>When you reach 8th level, and again at  12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Aura of Courage',
        level: 10,
        description: `
        <p>Starting at 10th level, you and friendly creatures within 10 feet of you can't be frightened while you are conscious.</p>
        <p>At 18th level, the range of this aura increases to 30 feet.</p>
        `,
      },
      {
        name: 'Improved Divine Smite',
        level: 11,
        description: `
        <p>By 11th level, you are so suffused with righteous might that all your melee weapon strikes carry divine power with them. Whenever you hit a creature with a melee weapon, the creature takes an extra 1d8 radiant damage.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 12,
        description: `
        <p>When you reach 12th level, and again at 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Cleansing Touch',
        level: 14,
        description: `
        <p>Beginning at 14th level, you can use your action to end one spell on yourself or on one willing creature that you touch.</p>
        <p>You can use this feature a number of times equal to your Charisma modifier (a minimum of once). You regain expended uses when you finish a long rest.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 16,
        description: `
        <p>When you reach 16th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
    ],
  };

  public wizard: any = {
    title: 'Wizard',
    description: `
    Wizards are supreme magic-users, defined and united as a class by the spells they cast. Drawing on the subtle weave of magic that permeates the cosmos, wizards cast spells of explosive fire, arcing lightning, subtle deception, brute-force mind control, and much more.
    <h4>Class Features</h4>
    <p>As a wizard, you gain the following class features.</p>
    <h4> Hit Points</h4>
    <b>Hit Dice:</b> 1d6 per wizard level <br>
    <b>Hit Points at 1st Level:</b> 6 + your Constitution modifier <br>
    <b>Hit Points at Higher Levels:</b> 1d6 (or 4) + your Constitution modifier per wizard level after 1st <br>
    <h4> Proficiencies</h4>
    <b>Armor:</b> None <br>
    <b>Weapons:</b> Daggers, darts, slings, quarterstaffs, light crossbows <br>
    <b>Tools:</b> None <br>
    <b>Saving Throws:</b> Intelligence, Wisdom <br>
    <b>Skills:</b> Choose two from Arcana, History, Insight, Investigation, Medicine, and Religion <br>
    <h4> Equipment</h4>
    <ul>
    <li> (a) a quarterstaff or (b) a dagger </li>
    <li> (a) a component pouch or (b) an arcane focus </li>
    <li> (a) a scholar's pack or (b) an explorer's pack </li>
    <li> A spellbook </li>
    </ul>
    `,
    features: [
      {
        name: 'Spellcasting',
        level: 1,
        description: `
        <p>As a student of arcane magic, you have a spellbook containing spells that show the first glimmerings of your true power.</p>
        <b id="toc5"><span>Cantrips</span></b>
        <p>At 1st level, you know three cantrips of your choice from the wizard spell list. You learn additional wizard cantrips of your choice at higher levels, as shown in the Cantrips Known column of the Wizard table.</p>
        <b id="toc6"><span>Spellbook</span></b>
        <p>At 1st level, you have a spellbook containing six 1st-level wizard spells of your choice. Your spellbook is the repository of the wizard spells you know, except your cantrips, which are fixed in your mind.</p>
        <p>The spells that you add to your spellbook as you gain levels reflect the arcane research you conduct on your own, as well as intellectual breakthroughs you have had about the nature of the multiverse. You might find other spells during your adventures. You could discover a spell recorded on a scroll in an evil wizard's chest, for example, or in a dusty tome in an ancient library.</p>
        <p><strong><em>Copying a Spell into the Book.</em></strong> When you find a wizard spell of 1st level or higher, you can add it to your spellbook if it is of a spell level you can prepare and if you can spare the time to decipher and copy it.</p>
        <p>Copying a spell into your spellbook involves reproducing the basic form of the spell, then deciphering the unique system of notation used by the wizard who wrote it. You must practice the spell until you understand the sounds or gestures required, then transcribe it into your spellbook using your own notation.</p>
        <p>For each level of the spell, the process takes 2 hours and costs 50 gp. The cost represents material components you expend as you experiment with the spell to master it, as well as the fine inks you need to record it. Once you have spent this time and money, you can prepare the spell just like your other spells.</p>
        <p><strong><em>Replacing the Book.</em></strong> You can copy a spell from your own spellbook into another book-for example, if you want to make a backup copy of your spellbook. This is just like copying a new spell into your spellbook, but faster and easier, since you understand your own notation and already know how to cast the spell. You need spend only 1 hour and 10 gp for each level of the copied spell.</p>
        <p>If you lose your spellbook, you can use the same procedure to transcribe the spells that you have prepared into a new spellbook. Filling out the remainder of your spellbook requires you to find new spells to do so, as normal. For this reason, many wizards keep backup spellbooks in a safe place.</p>
        <p><strong><em>The Book's Appearance.</em></strong> Your spellbook is a unique compilation of spells, with its own decorative flourishes and margin notes. It might be a plain, functional leather volume that you received as a gift from your master, a finely bound gilt-edged tome you found in an ancient library or even a loose collection of notes scrounged together after you lost your previous spellbook in a mishap.</p>
        <b id="toc7"><span>Preparing and Casting Spells</span></b>
        <p>The Wizard table shows how many spell slots you have to cast your wizard spells of 1st level and higher. To cast one of these spells, you must expend a slot of the spell's level or higher. You regain all expended spell slots when you finish a long rest.</p>
        <p>You prepare the list of wizard spells that are available for you to cast. To do so, choose a number of wizard spells from your spellbook equal to your Intelligence modifier + your wizard level (minimum of one spell). The spells must be of a level for which you have spell slots.</p>
        <p>For example, if you're a 3rd-level wizard, you have four 1st-level and two 2nd-level spell slots. With an Intelligence of 16, your list of prepared spells can include six spells of 1st or 2nd level, in any combination, chosen from your spellbook. If you prepare the 1st-level spell <em>magic missile</em>, you can cast it using a 1st-level or a 2nd-level slot. Casting the spell doesn't remove it from your list of prepared spells.</p>
        <p>You can change your list of prepared spells when you finish a long rest. Preparing a new list of wizard spells requires time spent studying your spellbook and memorizing the incantations and gestures you must make to cast the spell: at least 1 minute per spell level for each spell on your list.</p>
        <b id="toc8"><span>Spellcasting Ability</span></b>
        <p>Intelligence is your spellcasting ability for your wizard spells, since you learn your spells through dedicated study and memorization. You use your Intelligence whenever a spell refers to your spellcasting ability. In addition, you use your Intelligence modifier when setting the saving throw DC for a wizard spell you cast and when making an attack roll with one.</p>
        <p><strong>Spell save DC</strong> = 8 + your proficiency bonus + your Intelligence modifier</p>
        <p><strong>Spell attack modifier</strong> = your proficiency bonus + your Intelligence modifier</p>
        <b id="toc9"><span>Ritual Casting</span></b>
        <p>You can cast a wizard spell as a ritual if that spell has the ritual tag and you have the spell in your spellbook. You don't need to have the spell prepared.</p>
        <b id="toc10"><span>Spellcasting Focus</span></b>
        <p>You can use an arcane focus as a spellcasting focus for your wizard spells.</p>
        <b id="toc11"><span>Learning Spells of 1st Level and Higher</span></b>
        <p>Each time you gain a wizard level, you can add two wizard spells of your choice to your spellbook. Each of these spells must be of a level for which you have spell slots, as shown on the Wizard table. On your adventures, you might find other spells that you can add to your spellbook.</p>
        `,
      },
      {
        name: 'Arcane Recovery',
        level: 1,
        description: `
        <p>You have learned to regain some of your magical energy by studying your spellbook. Once per day when you finish a short rest, you can choose expended spell slots to recover. The spell slots can have a combined level that is equal to or less than half your wizard level (rounded up), and none of the slots can be 6th level or higher.</p>
        <p>For example, if you're a 4th-level wizard, you can recover up to two levels worth of spell slots. You can recover either a 2nd-level spell slot or two 1st-level spell slots.</p>
        `,
      },
      {
        name: 'Arcane Tradition',
        level: 2,
        description: `
        <p>When you reach 2nd level, you choose an arcane tradition, shaping your practice of magic through one of the following schools. Your choice grants you features at 2nd level and again at 6th, 10th, and 14th level.</p>
        `,
      },
      {
        name: 'Cantrip Formulas (Optional)',
        level: 3,
        description: `
        <p>At 3rd level, you have scribed a set of arcane formulas in your spellbook that you can use to formulate a cantrip in your mind. Whenever you finish a long rest and consult those formulas in your spellbook, you can replace one wizard cantrip you know with another cantrip from the wizard spell list.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 4,
        description: `
        <p>When you reach 4th level, and again at 8th, 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 8,
        description: `
        <p>When you reach 4th level, and again at 12th, 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 12,
        description: `
        <p>When you reach 12th level, and again at 16th, and 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Ability Score Improvement',
        level: 16,
        description: `
        <p>When you reach 16th level, and again at 19th level, you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Spell Mastery',
        level: 18,
        description: `
        <p>At 18th level, you have achieved such mastery over certain spells that you can cast them at will. Choose a 1st-level wizard spell and a 2nd-level wizard spell that are in your spellbook. You can cast those spells at their lowest level without expending a spell slot when you have them prepared. If you want to cast either spell at a higher level, you must expend a spell slot as normal.</p>
        <p>By spending 8 hours in study, you can exchange one or both of the spells you chose for different spells of the same levels.</p>
        `,
      },

      {
        name: 'Ability Score Improvement',
        level: 19,
        description: `
        <p>When you reach 19th level you can increase one ability score of your choice by 2, or you can increase two ability scores of your choice by 1. As normal, you can't increase an ability score above 20 using this feature.</p>
        `,
      },
      {
        name: 'Signature Spells',
        level: 20,
        description: `
        <p>When you reach 20th level, you gain mastery over two powerful spells and can cast them with little effort. Choose two 3rd-level wizard spells in your spellbook as your signature spells. You always have these spells prepared, they don't count against the number of spells you have prepared, and you can cast each of them once at 3rd level without expending a spell slot. When you do so, you can't do so again until you finish a short or long rest.</p>
        <p>If you want to cast either spell at a higher level, you must expend a spell slot as normal.</p>
        `,
      },
    ],
  };

  public warlock: any = {};

  public bard: any = {};

  public sorcerer: any = {};

  public druid: any = {};

  public rogue: any = {};

  private notImplementedYet: any = {
    title: 'Not implemented yet',
    description: `
    This class is not implemented yet, please check back later.
    `,
    features: [],
  };
}
